@@ -114,7 +114,7 @@
 #' [Online Documentation](
 #' https://dataquality.qihs.uni-greifswald.de/VIN_acc_impl_loess.html
 #' )
-#' @keywords internal
+#' @noRd
 util_acc_loess_continuous <- function(
     resp_vars,
     label_col = NULL,
@@ -139,12 +139,12 @@ util_acc_loess_continuous <- function(
     n_group_max = getOption("dataquieR.max_group_var_levels_in_plot",
                             dataquieR.max_group_var_levels_in_plot_default),
     enable_GAM = getOption("dataquieR.GAM_for_LOESS",
-                           dataquieR.GAM_for_LOESS.default),
+                           dataquieR.GAM_for_LOESS_default),
     exclude_constant_subgroups =
       getOption("dataquieR.acc_loess.exclude_constant_subgroups",
-                dataquieR.acc_loess.exclude_constant_subgroups.default),
+                dataquieR.acc_loess.exclude_constant_subgroups_default),
     min_bandwidth = getOption("dataquieR.acc_loess.min_bw",
-                              dataquieR.acc_loess.min_bw.default)) {
+                              dataquieR.acc_loess.min_bw_default)) {
   # preps ----------------------------------------------------------------------
   # map metadata to study data
   prep_prepare_dataframes(.replace_hard_limits = TRUE,
@@ -282,7 +282,9 @@ util_acc_loess_continuous <- function(
   }
 
   # convert group_vars to factor
-  ds1[[group_vars]] <- factor(ds1[[group_vars]])
+  if (!is.factor(ds1[[group_vars]])) {
+    ds1[[group_vars]] <- factor(ds1[[group_vars]])
+  }
 
   # TODO: use util_check_group_levels
   # too few observations per level?
@@ -310,7 +312,12 @@ util_acc_loess_continuous <- function(
                   ds1[[group_vars]] %in%
                     setdiff(levels(ds1[[group_vars]]), to_excl))
     # drop unused levels
-    ds1[[group_vars]] <- factor(ds1[[group_vars]])
+    if (!is.factor(ds1[[group_vars]])) {
+      ds1[[group_vars]] <- factor(ds1[[group_vars]])
+    } else {
+      ds1[[group_vars]] <-
+        droplevels(ds1[[group_vars]])
+    }
   }
 
   if (nrow(ds1) == 0) {
@@ -338,7 +345,12 @@ util_acc_loess_continuous <- function(
                     ds1[[group_vars]] %in%
                       setdiff(levels(ds1[[group_vars]]), lvl_to_exclude))
       # drop unused levels
-      ds1[[group_vars]] <- factor(ds1[[group_vars]])
+      if (!is.factor(ds1[[group_vars]])) {
+        ds1[[group_vars]] <- factor(ds1[[group_vars]])
+      } else {
+        ds1[[group_vars]] <-
+          droplevels(ds1[[group_vars]])
+      }
     }
   }
 
@@ -380,7 +392,7 @@ util_acc_loess_continuous <- function(
   tp_round_seq <- util_optimize_sequence_across_time_var(
     time_var_data = tp_seq,
     n_points = resolution)
-  ds1[["ROUND_TIME"]] <- suppressWarnings(as.POSIXct(
+  ds1[["ROUND_TIME"]] <- suppressWarnings(util_parse_date(
       lubridate::round_date(ds1[[time_vars]], unit = tp_round_seq)))
 
   # store a numeric version of the original time variable for later calculations
@@ -452,7 +464,7 @@ util_acc_loess_continuous <- function(
                f = bw_loess))
       fit_i_df <- unique(as.data.frame(fit_i))
       fit_vals <- fit_i_df$y
-      data_i_seq <- as.POSIXct(fit_i_df$x)
+      data_i_seq <- util_parse_date(fit_i_df$x)
     }
 
     pred_df <- data.frame(TIME = data_i_seq,
@@ -741,65 +753,102 @@ util_acc_loess_continuous <- function(
   y_max <- mean(ds1$Residuals) + sd(ds1$Residuals)
 
   # Facet-Grids for categorical variable (observer/device)
-  p1 <- ggplot(fit_groups,
-               aes(x = .data$TIME,
-                   y = .data$FITTED_VALUE,
-                   color = .data$GROUP)) + {
-                     if (!is.null(hex_code)) {
-                       scale_color_manual(values = hex_code)
-                     }
-                   } +
-    xlab(lines_info) +
-    ylab("") +
-    geom_dp_facets +
-    geom_obs_facets +
-    geom_line() +
-    facet_wrap(~ .data$GROUP, ncol = 2) + #TODO: What about this ~?
-    expand_limits(y = c(y_min, y_max)) +
-    theme_minimal() +
-    ggtitle(plot_title, subtitle) +
-    theme(legend.title = element_blank())
+  p1 <- util_create_lean_ggplot(
+    ggplot(fit_groups,
+           aes(x = .data$TIME,
+               y = .data$FITTED_VALUE,
+               color = .data$GROUP)) + {
+                 if (!is.null(hex_code)) {
+                   scale_color_manual(values = hex_code)
+                 }
+               } +
+      xlab(lines_info) +
+      ylab("") +
+      geom_dp_facets +
+      geom_obs_facets +
+      geom_line() +
+      facet_wrap(~ .data$GROUP, ncol = 2) + #TODO: What about this ~?
+      expand_limits(y = c(y_min, y_max)) +
+      theme_minimal() +
+      ggtitle(plot_title, subtitle) +
+      theme(legend.title = element_blank()),
+    fit_groups = fit_groups,
+    hex_code = hex_code,
+    lines_info = lines_info,
+    geom_dp_facets = geom_dp_facets,
+    geom_obs_facets = geom_obs_facets,
+    y_min = y_min,
+    y_max = y_max,
+    plot_title = plot_title,
+    subtitle = subtitle)
+
   if (any(compl)) {
-    p1 <- p1 +
-      geom_line(data = global_trends, aes(y = .data$low, group = NA),
-                color = lines_arg$color, linetype = lines_arg$linetype) +
-      geom_line(data = global_trends, aes(y = .data$mid, group = NA),
-                color = lines_arg$color, linetype = 1) +
-      geom_line(data = global_trends, aes(y = .data$high, group = NA),
-                color = lines_arg$color, linetype = lines_arg$linetype)
+    p1 <- util_create_lean_ggplot(
+      p1 +
+        geom_line(data = global_trends, aes(y = .data$low, group = NA),
+                  color = lines_arg$color, linetype = lines_arg$linetype) +
+        geom_line(data = global_trends, aes(y = .data$mid, group = NA),
+                  color = lines_arg$color, linetype = 1) +
+        geom_line(data = global_trends, aes(y = .data$high, group = NA),
+                  color = lines_arg$color, linetype = lines_arg$linetype),
+      p1 = p1,
+      global_trends = global_trends,
+      lines_arg = lines_arg)
   }
 
   # combined plot
-  p2 <- ggplot(fit_groups,
-               aes(x = .data$TIME,
-                   y = .data$FITTED_VALUE,
-                   group = .data$GROUP,
-                   color = .data$GROUP)) + {
-                     if (!is.null(hex_code)) {
-                       scale_color_manual(values = hex_code)
-                     }
-                   } +
-    xlab(lines_info) +
-    ylab("") +
-    geom_dp_comb +
-    geom_obs_comb +
-    geom_line() +
-    expand_limits(y = c(y_min, y_max)) +
-    theme_minimal() +
-    ggtitle(plot_title, subtitle)
+  p2 <- util_create_lean_ggplot(ggplot(fit_groups,
+                                       aes(x = .data$TIME,
+                                           y = .data$FITTED_VALUE,
+                                           group = .data$GROUP,
+                                           color = .data$GROUP)) + {
+                                             if (!is.null(hex_code)) {
+                                               scale_color_manual(values = hex_code)
+                                             }
+                                           } +
+                                  xlab(lines_info) +
+                                  ylab("") +
+                                  geom_dp_comb +
+                                  geom_obs_comb +
+                                  geom_line() +
+                                  expand_limits(y = c(y_min, y_max)) +
+                                  theme_minimal() +
+                                  ggtitle(plot_title, subtitle),
+                                fit_groups = fit_groups,
+                                hex_code = hex_code,
+                                lines_info = lines_info,
+                                geom_dp_comb = geom_dp_comb,
+                                geom_obs_comb = geom_obs_comb,
+                                y_min = y_min,
+                                y_max = y_max,
+                                plot_title = plot_title,
+                                subtitle = subtitle)
+
   if (any(compl)) {
-    p2 <- p2 +
-      geom_line(data = global_trends, aes(y = .data$low, group = NA),
-                color = lines_arg$color, linetype = lines_arg$linetype) +
-      geom_line(data = global_trends, aes(y = .data$mid, group = NA),
-                color = lines_arg$color, linetype = 1) +
-      geom_line(data = global_trends, aes(y = .data$high, group = NA),
-                color = lines_arg$color, linetype = lines_arg$linetype)
+    p2 <- util_create_lean_ggplot(
+      p2 +
+        geom_line(data = global_trends, aes(y = .data$low, group = NA),
+                  color = lines_arg$color, linetype = lines_arg$linetype) +
+        geom_line(data = global_trends, aes(y = .data$mid, group = NA),
+                  color = lines_arg$color, linetype = 1) +
+        geom_line(data = global_trends, aes(y = .data$high, group = NA),
+                  color = lines_arg$color, linetype = lines_arg$linetype),
+      p2 = p2,
+      global_trends = global_trends,
+      lines_arg = lines_arg)
   }
+
   if (length(levels(ds1[[group_vars]])) > 1) {
-    p2 <- p2 + theme(legend.title = element_blank())
+    p2 <- util_create_lean_ggplot(
+      p2 +
+        theme(legend.title = element_blank()),
+      p2 = p2)
+
   } else {
-    p2 <- p2 + theme(legend.position = "none")
+    p2 <-  util_create_lean_ggplot(
+      p2 +
+        theme(legend.position = "none"),
+      p2 = p2)
   }
 
   p1 <- util_set_size(p1,
@@ -818,7 +867,9 @@ util_acc_loess_continuous <- function(
 
   #Add attribute with size hints to the combined plot
   if (!is.null(pl[["Loess_fits_combined"]])) {
-    obj1 <- ggplot2::ggplot_build(pl[["Loess_fits_combined"]])
+    .plot1 <- pl[["Loess_fits_combined"]]
+    obj1 <- util_create_lean_ggplot(ggplot2::ggplot_build(.plot1),
+                                    .plot1= .plot1)
     min_point_line <- min(util_rbind(data_frames_list = obj1$data)$y, na.rm = TRUE)
     max_point_line <- max(util_rbind(data_frames_list = obj1$data)$y, na.rm = TRUE)
     n_groups <- length(unique(util_rbind(data_frames_list = obj1$data)$group))
