@@ -2,7 +2,7 @@ test_that("test-int_sts_element_dataframe works", {
   skip_on_cran() # online, fragile
   skip_if_offline(host = "dataquality.qihs.uni-greifswald.de")
   prep_load_workbook_like_file("https://dataquality.qihs.uni-greifswald.de/extdata/fortests/ship_meta_v2.xlsx")
-  sd0 <- prep_get_data_frame("https://dataquality.qihs.uni-greifswald.de/extdata/fortests/ship.RDS")
+  sd0 <- prep_get_data_frame("https://dataquality.qihs.uni-greifswald.de/extdata/fortests/ship.RDS", keep_types = TRUE)
   md0 <- prep_get_data_frame("item_level")
   dl0 <- prep_get_data_frame("dataframe_level")
   dl0$DF_NAME <- "https://dataquality.qihs.uni-greifswald.de/extdata/fortests/ship.RDS"
