@@ -2,7 +2,7 @@ test_that("int_unexp_records works", {
   skip_if_offline(host = "dataquality.qihs.uni-greifswald.de")
   skip_on_cran()
   skip("TODO") # TODO
-  sd1 <- prep_get_data_frame("https://dataquality.qihs.uni-greifswald.de/extdata/fortests/ship.RDS")
+  sd1 <- prep_get_data_frame("https://dataquality.qihs.uni-greifswald.de/extdata/fortests/ship.RDS", keep_types = TRUE)
   md1 <- prep_get_data_frame("https://dataquality.qihs.uni-greifswald.de/extdata/fortests/ship_meta.RDS")
 
   expect_error(
